Method: Time::TimeInEnglish#since

Defined in:
lib/mega/time_in_english.rb

#since(seconds) ⇒ Object Also known as: in

Returns a new Time representing the time a number of seconds since the instance time. Do not use this method in combination with x.months, use months_since instead!



127
128
129
130
131
# File 'lib/mega/time_in_english.rb', line 127

def since(seconds)
  # This is basically a wrapper around the Numeric extension.
  #seconds.since(self)
  self + seconds
end